==> openshift-client-4.11.1-sources.jar: io/fabric8/openshift/client/dsl/internal/KubeControllerManagerOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DoneableKubeControllerManager;
import io.fabric8.openshift.api.model.operator.v1.KubeControllerManager;
import io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerList;
import io.fabric8.openshift.api.model.operator.v1.DoneableKubeControllerManager;

import java.util.Map;
import java.util.TreeMap;


public class KubeControllerManagerOperationsImpl extends OpenShiftOperation<KubeControllerManager, KubeControllerManagerList, DoneableKubeControllerManager, Resource<KubeControllerManager, DoneableKubeControllerManager>> {

  public KubeControllerManagerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public KubeControllerManagerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("kubecontrollermanagers"));
    this.type = KubeControllerManager.class;
    this.listType = KubeControllerManagerList.class;
    this.doneableType = DoneableKubeControllerManager.class;
  }

  public KubeControllerManagerOperationsImpl newInstance(OperationContext context) {
    return new KubeControllerManagerOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.3.1-sources.jar: io/fabric8/openshift/client/dsl/internal/KubeControllerManagerOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.KubeControllerManager;
import io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerBuilder;
import io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerList;

import java.util.Map;
import java.util.TreeMap;


public class KubeControllerManagerOperationsImpl extends OpenShiftOperation<KubeControllerManager, KubeControllerManagerList, Resource<KubeControllerManager>> {

  public KubeControllerManagerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public KubeControllerManagerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("kubecontrollermanagers"));
    this.type = KubeControllerManager.class;
    this.listType = KubeControllerManagerList.class;
  }

  public KubeControllerManagerOperationsImpl newInstance(OperationContext context) {
    return new KubeControllerManagerOperationsImpl(context);
  }

  @Override
  public KubeControllerManager edit(Visitor... visitors) {
    return patch(new KubeControllerManagerBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
